"""AnyTLS 服务管理脚本 - 主入口"""

import typer

from anytls.cli import install, log, remove, start, stop, update, check
from anytls.logging_config import setup_logging

app = typer.Typer(
    name="anytls", help="mihomo-anytls-inbound manager", add_completion=False, no_args_is_help=False
)


@app.callback(invoke_without_command=True)
def main(ctx: typer.Context):
    """
    mihomo-anytls-inbound manager
    """
    setup_logging()

    # 如果没有提供子命令，显示帮助信息
    if ctx.invoked_subcommand is None:
        print(ctx.get_help())
        ctx.exit(0)


# 注册子命令
app.add_typer(install.app, name="install")
app.add_typer(remove.app, name="remove")
app.add_typer(log.app, name="log")
app.add_typer(start.app, name="start")
app.add_typer(stop.app, name="stop")
app.add_typer(update.app, name="update")
app.add_typer(check.app, name="check")

if __name__ == "__main__":
    app()



"""日志配置模块"""

import logging

from rich.logging import RichHandler


def setup_logging():
    """配置全局日志记录器"""
    logging.basicConfig(
        level=logging.INFO,
        format="%(message)s",
        datefmt="%Y-%m-%d %H:%M:%S",
        handlers=[RichHandler(rich_tracebacks=True, show_path=False, show_time=False)],
    )



"""全局常量配置"""

from pathlib import Path

BASE_DIR = Path("/home/anytls")
DOCKER_COMPOSE_PATH = BASE_DIR / "docker-compose.yaml"
CONFIG_PATH = BASE_DIR / "config.yaml"

LISTEN_PORT = 8443
SERVICE_IMAGE = "metacubex/mihomo:latest"

MIHOMO_ANYTLS_DOCS = "https://wiki.metacubex.one/config/proxies/anytls/#anytls"



"""Update 命令"""

import typer

from ..core.manager import AnyTLSManager

app = typer.Typer(help="更新服务镜像并重启。")


@app.callback(invoke_without_command=True)
def update():
    """
    更新服务镜像并重启。
    """
    manager = AnyTLSManager()
    manager.update()



"""Remove 命令"""

import typer

from ..core.manager import AnyTLSManager

app = typer.Typer(help="停止并移除 AnyTLS 服务。")


@app.callback(invoke_without_command=True)
def remove():
    """
    停止并移除 AnyTLS 服务。
    """
    manager = AnyTLSManager()
    manager.remove()
